@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0912';
+our $VERSION = '0.0913';
 
 use v5.36;
 
@@ -14,8 +14,8 @@ use IO::Async::Timer::Periodic ();
 use Iterator::Breathe ();
 use Moo;
 use Types::MIDI qw(Channel Velocity);
-use Types::Common::Numeric qw(NegativeNum PositiveNum);
-use Types::Standard qw(Bool Num Maybe);
+use Types::Common::Numeric qw(PositiveNum);
+use Types::Standard qw(Bool Maybe);
 use namespace::clean;
 
 
@@ -91,14 +91,14 @@ has time_step => (
 
 has step_up => (
     is      => 'rw',
-    isa     => Num,
+    isa     => Velocity, # no CC# in Types::MIDI yet
     default => 2,
 );
 
 
 has step_down => (
     is      => 'rw',
-    isa     => Num,
+    isa     => Velocity, # no CC# in Types::MIDI yet
     default => 1,
 );
 
@@ -376,7 +376,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0912
+version 0.0913
 
 =head1 SYNOPSIS
 
@@ -519,7 +519,8 @@ Default: C<1>
   $time_step = $filter->time_step;
   $filter->time_step($number);
 
-The current iteration step in seconds (probably fractions).
+A (probably fractional) positive number that is the current iteration
+step in seconds.
 
 Default: C<0.25> (a quarter of a second)
 
@@ -528,7 +529,8 @@ Default: C<0.25> (a quarter of a second)
   $step_up = $filter->step_up;
   $filter->step_up($number);
 
-The current iteration upward step. This can be any number.
+The current iteration upward step. This can be any whole number
+between C<0> and C<127>.
 
 Default: C<2>
 
@@ -537,7 +539,8 @@ Default: C<2>
   $step_down = $filter->step_down;
   $filter->step_down($number);
 
-The current iteration downward step. This can be any number.
+The current iteration downward step. This can be any whole number
+between C<0> and C<127>.
 
 Default: C<1>
 
